YARP 2.3.22 (2013-07-26)                                              {#v2_3_22}
========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.21...v2.3.22`):

```
     7	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
     6	Paul Fitzpatrick <paulfitz@alum.mit.edu>
     5	Alberto Cardellino <alberto.cardellino@iit.it>
     2	Matteo Brunettini <matteo.brunettini@iit.it>
     1	Elena Ceseracciu <elena.ceseracciu@iit.it>
     1	Lorenzo Natale <lorenzo.natale@iit.it>
```
